//
//  GLTrackPickerController.h
//  GLGPSKit
//
//  Created by Jeffrey Early on 2/3/10.
//  Copyright 2010 Early Innovations, LLC. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <GLMapKit/GLMapKit.h>
#import <GLGPSKit/GLTrackManager.h>

// This is a simple little controller that can be plopped into a project and provide
// a portal to the track manager. If you wire it up to a 

@class GLTrackPickerWindowController, GLTrackSourceList, GLSmartFile;
@interface GLTrackPickerController : NSObject <GLSpatialObjectController> {
	GLTrackPickerWindowController *windowController;
	GLTrackSourceList *trackSourceList;	
	id mapController;
	NSArray *spatialObjects;
	NSIndexSet *spatialObjectSelectionIndexes;
}

@property(strong, readonly) GLTrackPickerWindowController *windowController;
@property(nonatomic, strong) GLTrackSourceList *trackSourceList;

// GLGPSKit doesn't know anything about the the GLMapKit or its controllers, but
// you can wire this up to a map controller so that the zoom-to-fit functions work.
@property(nonatomic, strong) id mapController;

// The track manager from which the the above is derived.
@property(strong, readonly) GLTrackManager *trackManager;

/************************************************/
/*		Source Tree								*/
/************************************************/

#pragma mark -
#pragma mark Source Tree
#pragma mark

- (void) addSmartFile: (GLSmartFile *) smartFile;
- (void) removeSmartFile: (GLSmartFile *) smartFile;

@property(nonatomic, strong) id selectedSourceList;


/************************************************/
/*		IB Actions								*/
/************************************************/

#pragma mark -
#pragma mark IB Actions
#pragma mark

// Opens the window to the TrackPicker
- (IBAction) showWindow: (id) sender;

// Opens with window to the TrackPicker and the download from GPS sheet.
- (IBAction) downloadFromGPSAction: (id) sender;

// Opens with window to the TrackPicker and the an open panel.
- (IBAction) importFilesAction: (id) sender;


/************************************************/
/*		GLSpatialObjectController				*/
/************************************************/

#pragma mark -
#pragma mark GLSpatialObjectController
#pragma mark

@property(strong, readonly) NSString *name;
@property(nonatomic, strong) NSArray *spatialObjects;
@property(nonatomic, strong) NSIndexSet *spatialObjectSelectionIndexes;

@end
