//
//  GLExporter.h
//  MapProgram
//
//  Created by Jeffrey Early on 9/30/06.
//  Copyright 2006 Early Innovation. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <GLGeometryKit/GLGeometryKit.h>

@class GLMapDataSource, GLMapView;
@interface GLExporter : NSObject {
	NSImage		*backgroundMap;
	GLMapView	*_mapView;
}

typedef enum {
	kGLSelectionBoxVariableType,	// Any height width ratio, any scale
	kGLSelectionBoxFixedRatioType,	// Fixed height width ratio will be used
	kGLSelectionBoxFixedScaleType,	// Fixed scale (like 1:24000) will be used
} GLSelectionBoxType;

// instantiate and return valid instance
+ (GLExporter *) exporter;

// returns the exporters viewable name
- (NSString *) name;

// returns the exporters view to be shown when selected
- (NSView *) view;

// The export controller will keep tabs on the mapView and its selection box
// and update variables as appropriate. An exporter may use the datasource
// to determine currently available resolutions
@property(strong) GLMapView *mapView;

// this method should be called by all subclasses to invoke the export action.
// the method setBackgroundMap will be called first, followed by...
- (void) export;

// return what type of selection box rules should be used
- (GLSelectionBoxType) selectionBoxType;

// if a fixed ratio or scale is selected
- (float) selectionBoxHeightWidthRatio;

// if a fixed scale is selected
- (int) selectionBoxScale;

// if a fixed scale is selected, we need to know the destination size (paper size)
// Even if variable or ratio scale is selected, we need to know how to scale the geometry for the destination.
// In that case, selectionBoxHeightInMeters will be called. If a number less than zero is returned, it will be
// assumed that 72 dpi is intended and will therefore be based on the final map size.
- (double) selectionBoxHeightInMeters;
- (double) selectionBoxWidthInMeters;

// how many horizontal columns should be drawn (for page marks)
- (int) selectionBoxHorizontalGrid;

// how many vertical columns should be drawn (for page marks)
- (int) selectionBoxVerticalGrid;

// called to invoke export
- (void) exportWithDataSource: (GLMapDataSource *) dataSource projection: (GLMapProjection *) projection bounds: (GLRect) bounds resolution: (double) resolution spatialObjects: (NSArray *) spatialObjectArray;

@end
